@@ -10,7 +10,7 @@ use Const::Fast;
 use DateTime::Format::HTTP;
 use HTTP::Date;
 
-our $VERSION        = '3.2';
+our $VERSION        = '3.3';
 
 our $DateTimeCreate    = 1;
 our $ExtractProgram    = 1;
@@ -104,7 +104,7 @@ our @EXPORT_TAGS = (
 my %REGEXP = (
     stable => {
         preamble        => qr/^\<(\d+)\>/,
-        date            => qr/^([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
+        date            => qr/^(?:\d{4} )?([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
         date_long => qr/^
                 (?:[0-9]{4}\s+)?                # Year: Because, Cisco
                 ([.*])?                         # Cisco adds a * for no ntp, and a . for configured but out of sync
@@ -120,6 +120,7 @@ my %REGEXP = (
                 [0-9]{4}(\-[0-9]{2}){2}     # Date YYYY-MM-DD
                 (\s|T)                      # Date Separator T or ' '
                 [0-9]{2}(\:[0-9]{2}){1,2}   # Time HH:MM:SS
+                (?:\.(?:[0-9]{3}){1,2})?    # Time: .DDD millisecond or .DDDDDD microsecond resolution
                 ([+\-][0-9]{2}\:[0-9]{2})?  # UTC Offset +DD:MM
         )/x,
         host            => qr/^\s*([^:\s]+)\s+/,
@@ -132,7 +133,7 @@ my %REGEXP = (
     },
     devel => {
         preamble        => qr/^\<(\d+)\>/,
-        date            => qr/^([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
+        date            => qr/^(?:\d{4} )?([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
         date_long => qr/^
                 (?:[0-9]{4}\s+)?                # Year: Because, Cisco
                 ([.*])?                         # Cisco adds a * for no ntp, and a . for configured but out of sync
@@ -148,6 +149,7 @@ my %REGEXP = (
                 [0-9]{4}(?:\-[0-9]{2}){2}     # Date YYYY-MM-DD
                 (?:\s|T)                      # Date Separator T or ' '
                 [0-9]{2}(\:[0-9]{2}){1,2}   # Time HH:MM:SS
+                (?:\.(?:[0-9]{3}){1,2})?    # Time: .DDD millisecond or .DDDDDD microsecond resolution
                 (?:[+\-][0-9]{2}\:[0-9]{2})?  # UTC Offset +DD:MM
         )/x,
         host            => qr/^\s*([^:\s]+)\s+/,
@@ -163,7 +165,7 @@ my %REGEXP = (
 
 my %_empty_msg = map { $_ => undef } qw(
     preamble priority priority_int facility facility_int
-    datetime_raw date_raw date time date_str datetime_str datetime_obj epoch
+    datetime_raw date_raw date time datetime_str datetime_obj epoch
     host_raw host domain
     program_raw program_name program_pid program_sub
 );
@@ -220,7 +222,6 @@ sub parse_syslog_line {
             $msg{epoch}        = HTTP::Date::str2time($msg{datetime_raw});
             $msg{datetime_str} = HTTP::Date::time2iso($msg{epoch});
         }
-        $msg{date_str} = $msg{datetime_str} if exists $msg{datetime_str};
     }
 
     #
@@ -351,7 +352,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 3.2
+version 3.3
 
 =head1 SYNOPSIS
 
@@ -375,11 +376,9 @@ parsed out.
     #       time            => 'HH::MM:SS',
     #       epoch           => 1361095933,
     #       datetime_str    => 'YYYY-MM-DD HH:MM:SS',
-    #       datet_str       => 'YYYY-MM-DD HH:MM:SS',
     #       datetime_obj    => new DateTime(), # If installed
     #       datetime_raw    => 'Feb 17 11:12:13'
     #       date_raw        => 'Feb 17 11:12:13'
-    #       date_raw        => 'Feb 17 11:12:13'
     #       host_raw        => 'hostname',  # Hostname as it appeared in the message
     #       host            => 'hostname',  # Hostname without domain
     #       domain          => 'blah.com',  # if provided
@@ -465,7 +464,7 @@ This should be an array of fields you'd like to be removed from the hash referen
 
 Usage:
 
-  @Parse::Syslog::Line::PruneFields = qw(date_str date_raw facility_int priority_int);
+  @Parse::Syslog::Line::PruneFields = qw(date_raw facility_int priority_int);
 
 =head2 RegexSet
 
